@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from abc import ABCMeta
 from abc import abstractmethod
 from concurrent.futures._base import Executor
 from concurrent.futures._base import Future
@@ -7,6 +8,7 @@ from concurrent.futures.process import ProcessPoolExecutor
 from functools import reduce
 from pathlib import Path
 from typing import Any
+from typing import cast
 from typing import Dict
 from typing import Iterable
 from typing import Optional
@@ -20,13 +22,12 @@ from atomic_write_path import atomic_write_path
 
 from workflows.errors import RunTasksError
 from workflows.task import Task
-from workflows.task import TaskMeta
 
 
 T = TypeVar("T")
 
 
-class FileTaskMeta(TaskMeta):
+class FileTaskMeta(ABCMeta):
     def __new__(
         mcs: Type[FileTaskMeta],
         name: str,
@@ -57,7 +58,7 @@ class FileTaskMeta(TaskMeta):
 
             namespace[call_str] = __call__
 
-        return super().__new__(mcs, name, bases, namespace)
+        return cast(Type["FileTask"], super().__new__(mcs, name, bases, namespace))
 
 
 class FileTask(Task[T], metaclass=FileTaskMeta):
